# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

import fullbody_cartesian_command_pb2 as fullbody__cartesian__command__pb2


class FullBodyCartesianCommandServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.SendFullBodyCartesianCommands = channel.unary_unary(
                '/reachy.sdk.kinematics.FullBodyCartesianCommandService/SendFullBodyCartesianCommands',
                request_serializer=fullbody__cartesian__command__pb2.FullBodyCartesianCommand.SerializeToString,
                response_deserializer=fullbody__cartesian__command__pb2.FullBodyCartesianCommandAck.FromString,
                )
        self.StreamFullBodyCartesianCommands = channel.stream_unary(
                '/reachy.sdk.kinematics.FullBodyCartesianCommandService/StreamFullBodyCartesianCommands',
                request_serializer=fullbody__cartesian__command__pb2.FullBodyCartesianCommand.SerializeToString,
                response_deserializer=fullbody__cartesian__command__pb2.FullBodyCartesianCommandAck.FromString,
                )


class FullBodyCartesianCommandServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def SendFullBodyCartesianCommands(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StreamFullBodyCartesianCommands(self, request_iterator, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_FullBodyCartesianCommandServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'SendFullBodyCartesianCommands': grpc.unary_unary_rpc_method_handler(
                    servicer.SendFullBodyCartesianCommands,
                    request_deserializer=fullbody__cartesian__command__pb2.FullBodyCartesianCommand.FromString,
                    response_serializer=fullbody__cartesian__command__pb2.FullBodyCartesianCommandAck.SerializeToString,
            ),
            'StreamFullBodyCartesianCommands': grpc.stream_unary_rpc_method_handler(
                    servicer.StreamFullBodyCartesianCommands,
                    request_deserializer=fullbody__cartesian__command__pb2.FullBodyCartesianCommand.FromString,
                    response_serializer=fullbody__cartesian__command__pb2.FullBodyCartesianCommandAck.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'reachy.sdk.kinematics.FullBodyCartesianCommandService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class FullBodyCartesianCommandService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def SendFullBodyCartesianCommands(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/reachy.sdk.kinematics.FullBodyCartesianCommandService/SendFullBodyCartesianCommands',
            fullbody__cartesian__command__pb2.FullBodyCartesianCommand.SerializeToString,
            fullbody__cartesian__command__pb2.FullBodyCartesianCommandAck.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StreamFullBodyCartesianCommands(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_unary(request_iterator, target, '/reachy.sdk.kinematics.FullBodyCartesianCommandService/StreamFullBodyCartesianCommands',
            fullbody__cartesian__command__pb2.FullBodyCartesianCommand.SerializeToString,
            fullbody__cartesian__command__pb2.FullBodyCartesianCommandAck.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kinematics.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import joint_pb2 as joint__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10kinematics.proto\x12\x15reachy.sdk.kinematics\x1a\x0bjoint.proto\"J\n\rJointPosition\x12&\n\x03ids\x18\x01 \x03(\x0b\x32\x19.reachy.sdk.joint.JointId\x12\x11\n\tpositions\x18\x02 \x03(\x01\"\x19\n\tMatrix4x4\x12\x0c\n\x04\x64\x61ta\x18\x01 \x03(\x01\"8\n\nQuaternion\x12\t\n\x01w\x18\x01 \x01(\x01\x12\t\n\x01x\x18\x02 \x01(\x01\x12\t\n\x01y\x18\x03 \x01(\x01\x12\t\n\x01z\x18\x04 \x01(\x01\x62\x06proto3')



_JOINTPOSITION = DESCRIPTOR.message_types_by_name['JointPosition']
_MATRIX4X4 = DESCRIPTOR.message_types_by_name['Matrix4x4']
_QUATERNION = DESCRIPTOR.message_types_by_name['Quaternion']
JointPosition = _reflection.GeneratedProtocolMessageType('JointPosition', (_message.Message,), {
  'DESCRIPTOR' : _JOINTPOSITION,
  '__module__' : 'kinematics_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.kinematics.JointPosition)
  })
_sym_db.RegisterMessage(JointPosition)

Matrix4x4 = _reflection.GeneratedProtocolMessageType('Matrix4x4', (_message.Message,), {
  'DESCRIPTOR' : _MATRIX4X4,
  '__module__' : 'kinematics_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.kinematics.Matrix4x4)
  })
_sym_db.RegisterMessage(Matrix4x4)

Quaternion = _reflection.GeneratedProtocolMessageType('Quaternion', (_message.Message,), {
  'DESCRIPTOR' : _QUATERNION,
  '__module__' : 'kinematics_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.kinematics.Quaternion)
  })
_sym_db.RegisterMessage(Quaternion)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _JOINTPOSITION._serialized_start=56
  _JOINTPOSITION._serialized_end=130
  _MATRIX4X4._serialized_start=132
  _MATRIX4X4._serialized_end=157
  _QUATERNION._serialized_start=159
  _QUATERNION._serialized_end=215
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: orbita_kinematics.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import kinematics_pb2 as kinematics__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17orbita_kinematics.proto\x12\x15reachy.sdk.kinematics\x1a\x10kinematics.proto\"?\n\x0fOrbitaIKRequest\x12,\n\x01q\x18\x01 \x01(\x0b\x32!.reachy.sdk.kinematics.Quaternionb\x06proto3')



_ORBITAIKREQUEST = DESCRIPTOR.message_types_by_name['OrbitaIKRequest']
OrbitaIKRequest = _reflection.GeneratedProtocolMessageType('OrbitaIKRequest', (_message.Message,), {
  'DESCRIPTOR' : _ORBITAIKREQUEST,
  '__module__' : 'orbita_kinematics_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.kinematics.OrbitaIKRequest)
  })
_sym_db.RegisterMessage(OrbitaIKRequest)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ORBITAIKREQUEST._serialized_start=68
  _ORBITAIKREQUEST._serialized_end=131
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: any_mobile_base_command.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
import mobile_platform_reachy_pb2 as mobile__platform__reachy__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x61ny_mobile_base_command.proto\x12\x13reachy.sdk.mobility\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cmobile_platform_reachy.proto\"=\n\x14ResetOdometryMessage\x12%\n\x05reset\x18\x01 \x01(\x0b\x32\x16.google.protobuf.Empty\"\x8b\x03\n\x14\x41nyMobileBaseCommand\x12;\n\x08presence\x18\x01 \x01(\x0b\x32\'.reachy.sdk.mobility.MobileBasePresenceH\x00\x12G\n\x10target_direction\x18\x02 \x01(\x0b\x32+.reachy.sdk.mobility.TargetDirectionCommandH\x00\x12<\n\x0cmode_command\x18\x03 \x01(\x0b\x32$.reachy.sdk.mobility.ZuuuModeCommandH\x00\x12\x30\n\x05go_to\x18\x04 \x01(\x0b\x32\x1f.reachy.sdk.mobility.GoToVectorH\x00\x12\x43\n\x0ereset_odometry\x18\x05 \x01(\x0b\x32).reachy.sdk.mobility.ResetOdometryMessageH\x00\x12-\n\ttimestamp\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.TimestampB\t\n\x07\x63ommandb\x06proto3')



_RESETODOMETRYMESSAGE = DESCRIPTOR.message_types_by_name['ResetOdometryMessage']
_ANYMOBILEBASECOMMAND = DESCRIPTOR.message_types_by_name['AnyMobileBaseCommand']
ResetOdometryMessage = _reflection.GeneratedProtocolMessageType('ResetOdometryMessage', (_message.Message,), {
  'DESCRIPTOR' : _RESETODOMETRYMESSAGE,
  '__module__' : 'any_mobile_base_command_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.mobility.ResetOdometryMessage)
  })
_sym_db.RegisterMessage(ResetOdometryMessage)

AnyMobileBaseCommand = _reflection.GeneratedProtocolMessageType('AnyMobileBaseCommand', (_message.Message,), {
  'DESCRIPTOR' : _ANYMOBILEBASECOMMAND,
  '__module__' : 'any_mobile_base_command_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.mobility.AnyMobileBaseCommand)
  })
_sym_db.RegisterMessage(AnyMobileBaseCommand)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _RESETODOMETRYMESSAGE._serialized_start=146
  _RESETODOMETRYMESSAGE._serialized_end=207
  _ANYMOBILEBASECOMMAND._serialized_start=210
  _ANYMOBILEBASECOMMAND._serialized_end=605
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fan.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\tfan.proto\x12\x0ereachy.sdk.fan\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1bgoogle/protobuf/empty.proto\",\n\x05\x46\x61nId\x12\x0e\n\x04name\x18\x01 \x01(\tH\x00\x12\r\n\x03uid\x18\x02 \x01(\rH\x00\x42\x04\n\x02id\"%\n\x06\x46\x61nsId\x12\r\n\x05names\x18\x01 \x03(\t\x12\x0c\n\x04uids\x18\x02 \x03(\r\"e\n\x10\x46\x61nsStateRequest\x12\"\n\x03ids\x18\x01 \x03(\x0b\x32\x15.reachy.sdk.fan.FanId\x12-\n\ttimestamp\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x16\n\x08\x46\x61nState\x12\n\n\x02on\x18\x01 \x01(\x08\"\x88\x01\n\tFansState\x12\"\n\x03ids\x18\x01 \x03(\x0b\x32\x15.reachy.sdk.fan.FanId\x12(\n\x06states\x18\x02 \x03(\x0b\x32\x18.reachy.sdk.fan.FanState\x12-\n\ttimestamp\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.Timestamp\";\n\nFanCommand\x12!\n\x02id\x18\x01 \x01(\x0b\x32\x15.reachy.sdk.fan.FanId\x12\n\n\x02on\x18\x02 \x01(\x08\"j\n\x0b\x46\x61nsCommand\x12,\n\x08\x63ommands\x18\x01 \x03(\x0b\x32\x1a.reachy.sdk.fan.FanCommand\x12-\n\ttimestamp\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"!\n\x0e\x46\x61nsCommandAck\x12\x0f\n\x07success\x18\x01 \x01(\x08\x32\xf4\x01\n\x14\x46\x61nControllerService\x12>\n\x0cGetAllFansId\x12\x16.google.protobuf.Empty\x1a\x16.reachy.sdk.fan.FansId\x12K\n\x0cGetFansState\x12 .reachy.sdk.fan.FansStateRequest\x1a\x19.reachy.sdk.fan.FansState\x12O\n\x10SendFansCommands\x12\x1b.reachy.sdk.fan.FansCommand\x1a\x1e.reachy.sdk.fan.FansCommandAckb\x06proto3')



_FANID = DESCRIPTOR.message_types_by_name['FanId']
_FANSID = DESCRIPTOR.message_types_by_name['FansId']
_FANSSTATEREQUEST = DESCRIPTOR.message_types_by_name['FansStateRequest']
_FANSTATE = DESCRIPTOR.message_types_by_name['FanState']
_FANSSTATE = DESCRIPTOR.message_types_by_name['FansState']
_FANCOMMAND = DESCRIPTOR.message_types_by_name['FanCommand']
_FANSCOMMAND = DESCRIPTOR.message_types_by_name['FansCommand']
_FANSCOMMANDACK = DESCRIPTOR.message_types_by_name['FansCommandAck']
FanId = _reflection.GeneratedProtocolMessageType('FanId', (_message.Message,), {
  'DESCRIPTOR' : _FANID,
  '__module__' : 'fan_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.fan.FanId)
  })
_sym_db.RegisterMessage(FanId)

FansId = _reflection.GeneratedProtocolMessageType('FansId', (_message.Message,), {
  'DESCRIPTOR' : _FANSID,
  '__module__' : 'fan_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.fan.FansId)
  })
_sym_db.RegisterMessage(FansId)

FansStateRequest = _reflection.GeneratedProtocolMessageType('FansStateRequest', (_message.Message,), {
  'DESCRIPTOR' : _FANSSTATEREQUEST,
  '__module__' : 'fan_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.fan.FansStateRequest)
  })
_sym_db.RegisterMessage(FansStateRequest)

FanState = _reflection.GeneratedProtocolMessageType('FanState', (_message.Message,), {
  'DESCRIPTOR' : _FANSTATE,
  '__module__' : 'fan_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.fan.FanState)
  })
_sym_db.RegisterMessage(FanState)

FansState = _reflection.GeneratedProtocolMessageType('FansState', (_message.Message,), {
  'DESCRIPTOR' : _FANSSTATE,
  '__module__' : 'fan_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.fan.FansState)
  })
_sym_db.RegisterMessage(FansState)

FanCommand = _reflection.GeneratedProtocolMessageType('FanCommand', (_message.Message,), {
  'DESCRIPTOR' : _FANCOMMAND,
  '__module__' : 'fan_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.fan.FanCommand)
  })
_sym_db.RegisterMessage(FanCommand)

FansCommand = _reflection.GeneratedProtocolMessageType('FansCommand', (_message.Message,), {
  'DESCRIPTOR' : _FANSCOMMAND,
  '__module__' : 'fan_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.fan.FansCommand)
  })
_sym_db.RegisterMessage(FansCommand)

FansCommandAck = _reflection.GeneratedProtocolMessageType('FansCommandAck', (_message.Message,), {
  'DESCRIPTOR' : _FANSCOMMANDACK,
  '__module__' : 'fan_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.fan.FansCommandAck)
  })
_sym_db.RegisterMessage(FansCommandAck)

_FANCONTROLLERSERVICE = DESCRIPTOR.services_by_name['FanControllerService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _FANID._serialized_start=91
  _FANID._serialized_end=135
  _FANSID._serialized_start=137
  _FANSID._serialized_end=174
  _FANSSTATEREQUEST._serialized_start=176
  _FANSSTATEREQUEST._serialized_end=277
  _FANSTATE._serialized_start=279
  _FANSTATE._serialized_end=301
  _FANSSTATE._serialized_start=304
  _FANSSTATE._serialized_end=440
  _FANCOMMAND._serialized_start=442
  _FANCOMMAND._serialized_end=501
  _FANSCOMMAND._serialized_start=503
  _FANSCOMMAND._serialized_end=609
  _FANSCOMMANDACK._serialized_start=611
  _FANSCOMMANDACK._serialized_end=644
  _FANCONTROLLERSERVICE._serialized_start=647
  _FANCONTROLLERSERVICE._serialized_end=891
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: joint.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0bjoint.proto\x12\x10reachy.sdk.joint\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1bgoogle/protobuf/empty.proto\"+\n\x08PIDGains\x12\t\n\x01p\x18\x01 \x01(\x02\x12\t\n\x01i\x18\x02 \x01(\x02\x12\t\n\x01\x64\x18\x03 \x01(\x02\"\x8f\x01\n\x15\x43omplianceMarginSlope\x12\x1c\n\x14\x63w_compliance_margin\x18\x01 \x01(\x02\x12\x1d\n\x15\x63\x63w_compliance_margin\x18\x02 \x01(\x02\x12\x1b\n\x13\x63w_compliance_slope\x18\x03 \x01(\x02\x12\x1c\n\x14\x63\x63w_compliance_slope\x18\x04 \x01(\x02\"}\n\x08PIDValue\x12)\n\x03pid\x18\x01 \x01(\x0b\x32\x1a.reachy.sdk.joint.PIDGainsH\x00\x12=\n\ncompliance\x18\x02 \x01(\x0b\x32\'.reachy.sdk.joint.ComplianceMarginSlopeH\x00\x42\x07\n\x05gains\".\n\x07JointId\x12\x0e\n\x04name\x18\x01 \x01(\tH\x00\x12\r\n\x03uid\x18\x02 \x01(\rH\x00\x42\x04\n\x02id\"\x86\x04\n\nJointState\x12\x0c\n\x04name\x18\x01 \x01(\t\x12)\n\x03uid\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x35\n\x10present_position\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\x12\x32\n\rpresent_speed\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\x12\x31\n\x0cpresent_load\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\x12\x30\n\x0btemperature\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\x12-\n\tcompliant\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x32\n\rgoal_position\x18\x08 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\x12\x30\n\x0bspeed_limit\x18\t \x01(\x0b\x32\x1b.google.protobuf.FloatValue\x12\x31\n\x0ctorque_limit\x18\n \x01(\x0b\x32\x1b.google.protobuf.FloatValue\x12\'\n\x03pid\x18\x0b \x01(\x0b\x32\x1a.reachy.sdk.joint.PIDValue\"\x92\x01\n\x0bJointsState\x12&\n\x03ids\x18\x01 \x03(\x0b\x32\x19.reachy.sdk.joint.JointId\x12,\n\x06states\x18\x02 \x03(\x0b\x32\x1c.reachy.sdk.joint.JointState\x12-\n\ttimestamp\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\'\n\x08JointsId\x12\r\n\x05names\x18\x01 \x03(\t\x12\x0c\n\x04uids\x18\x02 \x03(\r\"\xa3\x01\n\x12JointsStateRequest\x12&\n\x03ids\x18\x01 \x03(\x0b\x32\x19.reachy.sdk.joint.JointId\x12\x36\n\x10requested_fields\x18\x02 \x03(\x0e\x32\x1c.reachy.sdk.joint.JointField\x12-\n\ttimestamp\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x96\x01\n\x13StreamJointsRequest\x12\x35\n\x07request\x18\x01 \x01(\x0b\x32$.reachy.sdk.joint.JointsStateRequest\x12\x19\n\x11publish_frequency\x18\x02 \x01(\x02\x12-\n\ttimestamp\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xa6\x02\n\x0cJointCommand\x12%\n\x02id\x18\x01 \x01(\x0b\x32\x19.reachy.sdk.joint.JointId\x12-\n\tcompliant\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x32\n\rgoal_position\x18\x08 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\x12\x30\n\x0bspeed_limit\x18\t \x01(\x0b\x32\x1b.google.protobuf.FloatValue\x12\x31\n\x0ctorque_limit\x18\n \x01(\x0b\x32\x1b.google.protobuf.FloatValue\x12\'\n\x03pid\x18\x0b \x01(\x0b\x32\x1a.reachy.sdk.joint.PIDValue\"p\n\rJointsCommand\x12\x30\n\x08\x63ommands\x18\x01 \x03(\x0b\x32\x1e.reachy.sdk.joint.JointCommand\x12-\n\ttimestamp\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"#\n\x10JointsCommandAck\x12\x0f\n\x07success\x18\x01 \x01(\x08*\xcc\x01\n\nJointField\x12\x08\n\x04NONE\x10\x00\x12\x08\n\x04NAME\x10\x01\x12\x07\n\x03UID\x10\x02\x12\x14\n\x10PRESENT_POSITION\x10\x03\x12\x11\n\rPRESENT_SPEED\x10\x04\x12\x10\n\x0cPRESENT_LOAD\x10\x05\x12\x0f\n\x0bTEMPERATURE\x10\x06\x12\r\n\tCOMPLIANT\x10\x07\x12\x11\n\rGOAL_POSITION\x10\x08\x12\x0f\n\x0bSPEED_LIMIT\x10\t\x12\x10\n\x0cTORQUE_LIMIT\x10\n\x12\x07\n\x03PID\x10\x0b\x12\x07\n\x03\x41LL\x10\x0f\x32\xc2\x03\n\x0cJointService\x12\x44\n\x0eGetAllJointsId\x12\x16.google.protobuf.Empty\x1a\x1a.reachy.sdk.joint.JointsId\x12U\n\x0eGetJointsState\x12$.reachy.sdk.joint.JointsStateRequest\x1a\x1d.reachy.sdk.joint.JointsState\x12[\n\x11StreamJointsState\x12%.reachy.sdk.joint.StreamJointsRequest\x1a\x1d.reachy.sdk.joint.JointsState0\x01\x12Y\n\x12SendJointsCommands\x12\x1f.reachy.sdk.joint.JointsCommand\x1a\".reachy.sdk.joint.JointsCommandAck\x12]\n\x14StreamJointsCommands\x12\x1f.reachy.sdk.joint.JointsCommand\x1a\".reachy.sdk.joint.JointsCommandAck(\x01\x62\x06proto3')

_JOINTFIELD = DESCRIPTOR.enum_types_by_name['JointField']
JointField = enum_type_wrapper.EnumTypeWrapper(_JOINTFIELD)
NONE = 0
NAME = 1
UID = 2
PRESENT_POSITION = 3
PRESENT_SPEED = 4
PRESENT_LOAD = 5
TEMPERATURE = 6
COMPLIANT = 7
GOAL_POSITION = 8
SPEED_LIMIT = 9
TORQUE_LIMIT = 10
PID = 11
ALL = 15


_PIDGAINS = DESCRIPTOR.message_types_by_name['PIDGains']
_COMPLIANCEMARGINSLOPE = DESCRIPTOR.message_types_by_name['ComplianceMarginSlope']
_PIDVALUE = DESCRIPTOR.message_types_by_name['PIDValue']
_JOINTID = DESCRIPTOR.message_types_by_name['JointId']
_JOINTSTATE = DESCRIPTOR.message_types_by_name['JointState']
_JOINTSSTATE = DESCRIPTOR.message_types_by_name['JointsState']
_JOINTSID = DESCRIPTOR.message_types_by_name['JointsId']
_JOINTSSTATEREQUEST = DESCRIPTOR.message_types_by_name['JointsStateRequest']
_STREAMJOINTSREQUEST = DESCRIPTOR.message_types_by_name['StreamJointsRequest']
_JOINTCOMMAND = DESCRIPTOR.message_types_by_name['JointCommand']
_JOINTSCOMMAND = DESCRIPTOR.message_types_by_name['JointsCommand']
_JOINTSCOMMANDACK = DESCRIPTOR.message_types_by_name['JointsCommandAck']
PIDGains = _reflection.GeneratedProtocolMessageType('PIDGains', (_message.Message,), {
  'DESCRIPTOR' : _PIDGAINS,
  '__module__' : 'joint_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.joint.PIDGains)
  })
_sym_db.RegisterMessage(PIDGains)

ComplianceMarginSlope = _reflection.GeneratedProtocolMessageType('ComplianceMarginSlope', (_message.Message,), {
  'DESCRIPTOR' : _COMPLIANCEMARGINSLOPE,
  '__module__' : 'joint_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.joint.ComplianceMarginSlope)
  })
_sym_db.RegisterMessage(ComplianceMarginSlope)

PIDValue = _reflection.GeneratedProtocolMessageType('PIDValue', (_message.Message,), {
  'DESCRIPTOR' : _PIDVALUE,
  '__module__' : 'joint_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.joint.PIDValue)
  })
_sym_db.RegisterMessage(PIDValue)

JointId = _reflection.GeneratedProtocolMessageType('JointId', (_message.Message,), {
  'DESCRIPTOR' : _JOINTID,
  '__module__' : 'joint_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.joint.JointId)
  })
_sym_db.RegisterMessage(JointId)

JointState = _reflection.GeneratedProtocolMessageType('JointState', (_message.Message,), {
  'DESCRIPTOR' : _JOINTSTATE,
  '__module__' : 'joint_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.joint.JointState)
  })
_sym_db.RegisterMessage(JointState)

JointsState = _reflection.GeneratedProtocolMessageType('JointsState', (_message.Message,), {
  'DESCRIPTOR' : _JOINTSSTATE,
  '__module__' : 'joint_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.joint.JointsState)
  })
_sym_db.RegisterMessage(JointsState)

JointsId = _reflection.GeneratedProtocolMessageType('JointsId', (_message.Message,), {
  'DESCRIPTOR' : _JOINTSID,
  '__module__' : 'joint_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.joint.JointsId)
  })
_sym_db.RegisterMessage(JointsId)

JointsStateRequest = _reflection.GeneratedProtocolMessageType('JointsStateRequest', (_message.Message,), {
  'DESCRIPTOR' : _JOINTSSTATEREQUEST,
  '__module__' : 'joint_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.joint.JointsStateRequest)
  })
_sym_db.RegisterMessage(JointsStateRequest)

StreamJointsRequest = _reflection.GeneratedProtocolMessageType('StreamJointsRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMJOINTSREQUEST,
  '__module__' : 'joint_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.joint.StreamJointsRequest)
  })
_sym_db.RegisterMessage(StreamJointsRequest)

JointCommand = _reflection.GeneratedProtocolMessageType('JointCommand', (_message.Message,), {
  'DESCRIPTOR' : _JOINTCOMMAND,
  '__module__' : 'joint_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.joint.JointCommand)
  })
_sym_db.RegisterMessage(JointCommand)

JointsCommand = _reflection.GeneratedProtocolMessageType('JointsCommand', (_message.Message,), {
  'DESCRIPTOR' : _JOINTSCOMMAND,
  '__module__' : 'joint_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.joint.JointsCommand)
  })
_sym_db.RegisterMessage(JointsCommand)

JointsCommandAck = _reflection.GeneratedProtocolMessageType('JointsCommandAck', (_message.Message,), {
  'DESCRIPTOR' : _JOINTSCOMMANDACK,
  '__module__' : 'joint_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.joint.JointsCommandAck)
  })
_sym_db.RegisterMessage(JointsCommandAck)

_JOINTSERVICE = DESCRIPTOR.services_by_name['JointService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _JOINTFIELD._serialized_start=1972
  _JOINTFIELD._serialized_end=2176
  _PIDGAINS._serialized_start=127
  _PIDGAINS._serialized_end=170
  _COMPLIANCEMARGINSLOPE._serialized_start=173
  _COMPLIANCEMARGINSLOPE._serialized_end=316
  _PIDVALUE._serialized_start=318
  _PIDVALUE._serialized_end=443
  _JOINTID._serialized_start=445
  _JOINTID._serialized_end=491
  _JOINTSTATE._serialized_start=494
  _JOINTSTATE._serialized_end=1012
  _JOINTSSTATE._serialized_start=1015
  _JOINTSSTATE._serialized_end=1161
  _JOINTSID._serialized_start=1163
  _JOINTSID._serialized_end=1202
  _JOINTSSTATEREQUEST._serialized_start=1205
  _JOINTSSTATEREQUEST._serialized_end=1368
  _STREAMJOINTSREQUEST._serialized_start=1371
  _STREAMJOINTSREQUEST._serialized_end=1521
  _JOINTCOMMAND._serialized_start=1524
  _JOINTCOMMAND._serialized_end=1818
  _JOINTSCOMMAND._serialized_start=1820
  _JOINTSCOMMAND._serialized_end=1932
  _JOINTSCOMMANDACK._serialized_start=1934
  _JOINTSCOMMANDACK._serialized_end=1969
  _JOINTSERVICE._serialized_start=2179
  _JOINTSERVICE._serialized_end=2629
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: trajectory.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10trajectory.proto\x12\x15reachy.sdk.trajectory\x1a\x1egoogle/protobuf/wrappers.proto\"\xd9\x01\n\x11TrajectoryRequest\x12\x36\n\x11starting_position\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\x12\x34\n\x0ftarget_position\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\x12-\n\x08\x64uration\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\x12\'\n\x02\x64t\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\"+\n\nTrajectory\x12\x11\n\tpositions\x18\x01 \x03(\x01\x12\n\n\x02\x64t\x18\x02 \x01(\x01\x32\x80\x01\n\x11TrajectoryService\x12k\n\x1c\x43omputeMinimumJerkTrajectory\x12(.reachy.sdk.trajectory.TrajectoryRequest\x1a!.reachy.sdk.trajectory.Trajectoryb\x06proto3')



_TRAJECTORYREQUEST = DESCRIPTOR.message_types_by_name['TrajectoryRequest']
_TRAJECTORY = DESCRIPTOR.message_types_by_name['Trajectory']
TrajectoryRequest = _reflection.GeneratedProtocolMessageType('TrajectoryRequest', (_message.Message,), {
  'DESCRIPTOR' : _TRAJECTORYREQUEST,
  '__module__' : 'trajectory_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.trajectory.TrajectoryRequest)
  })
_sym_db.RegisterMessage(TrajectoryRequest)

Trajectory = _reflection.GeneratedProtocolMessageType('Trajectory', (_message.Message,), {
  'DESCRIPTOR' : _TRAJECTORY,
  '__module__' : 'trajectory_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.trajectory.Trajectory)
  })
_sym_db.RegisterMessage(Trajectory)

_TRAJECTORYSERVICE = DESCRIPTOR.services_by_name['TrajectoryService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _TRAJECTORYREQUEST._serialized_start=76
  _TRAJECTORYREQUEST._serialized_end=293
  _TRAJECTORY._serialized_start=295
  _TRAJECTORY._serialized_end=338
  _TRAJECTORYSERVICE._serialized_start=341
  _TRAJECTORYSERVICE._serialized_end=469
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

import camera_reachy_pb2 as camera__reachy__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


class CameraServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetImage = channel.unary_unary(
                '/reachy.sdk.camera.CameraService/GetImage',
                request_serializer=camera__reachy__pb2.ImageRequest.SerializeToString,
                response_deserializer=camera__reachy__pb2.Image.FromString,
                )
        self.StreamImage = channel.unary_stream(
                '/reachy.sdk.camera.CameraService/StreamImage',
                request_serializer=camera__reachy__pb2.StreamImageRequest.SerializeToString,
                response_deserializer=camera__reachy__pb2.Image.FromString,
                )
        self.GetZoomLevel = channel.unary_unary(
                '/reachy.sdk.camera.CameraService/GetZoomLevel',
                request_serializer=camera__reachy__pb2.Camera.SerializeToString,
                response_deserializer=camera__reachy__pb2.ZoomLevel.FromString,
                )
        self.GetZoomSpeed = channel.unary_unary(
                '/reachy.sdk.camera.CameraService/GetZoomSpeed',
                request_serializer=camera__reachy__pb2.Camera.SerializeToString,
                response_deserializer=camera__reachy__pb2.ZoomSpeed.FromString,
                )
        self.SendZoomCommand = channel.unary_unary(
                '/reachy.sdk.camera.CameraService/SendZoomCommand',
                request_serializer=camera__reachy__pb2.ZoomCommand.SerializeToString,
                response_deserializer=camera__reachy__pb2.ZoomCommandAck.FromString,
                )
        self.GetZoomFocus = channel.unary_unary(
                '/reachy.sdk.camera.CameraService/GetZoomFocus',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=camera__reachy__pb2.ZoomFocusMessage.FromString,
                )
        self.SetZoomFocus = channel.unary_unary(
                '/reachy.sdk.camera.CameraService/SetZoomFocus',
                request_serializer=camera__reachy__pb2.ZoomFocusMessage.SerializeToString,
                response_deserializer=camera__reachy__pb2.ZoomCommandAck.FromString,
                )
        self.StartAutofocus = channel.unary_unary(
                '/reachy.sdk.camera.CameraService/StartAutofocus',
                request_serializer=camera__reachy__pb2.Camera.SerializeToString,
                response_deserializer=camera__reachy__pb2.ZoomCommandAck.FromString,
                )
        self.StopAutofocus = channel.unary_unary(
                '/reachy.sdk.camera.CameraService/StopAutofocus',
                request_serializer=camera__reachy__pb2.Camera.SerializeToString,
                response_deserializer=camera__reachy__pb2.ZoomCommandAck.FromString,
                )


class CameraServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetImage(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StreamImage(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetZoomLevel(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetZoomSpeed(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SendZoomCommand(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetZoomFocus(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetZoomFocus(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StartAutofocus(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StopAutofocus(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_CameraServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetImage': grpc.unary_unary_rpc_method_handler(
                    servicer.GetImage,
                    request_deserializer=camera__reachy__pb2.ImageRequest.FromString,
                    response_serializer=camera__reachy__pb2.Image.SerializeToString,
            ),
            'StreamImage': grpc.unary_stream_rpc_method_handler(
                    servicer.StreamImage,
                    request_deserializer=camera__reachy__pb2.StreamImageRequest.FromString,
                    response_serializer=camera__reachy__pb2.Image.SerializeToString,
            ),
            'GetZoomLevel': grpc.unary_unary_rpc_method_handler(
                    servicer.GetZoomLevel,
                    request_deserializer=camera__reachy__pb2.Camera.FromString,
                    response_serializer=camera__reachy__pb2.ZoomLevel.SerializeToString,
            ),
            'GetZoomSpeed': grpc.unary_unary_rpc_method_handler(
                    servicer.GetZoomSpeed,
                    request_deserializer=camera__reachy__pb2.Camera.FromString,
                    response_serializer=camera__reachy__pb2.ZoomSpeed.SerializeToString,
            ),
            'SendZoomCommand': grpc.unary_unary_rpc_method_handler(
                    servicer.SendZoomCommand,
                    request_deserializer=camera__reachy__pb2.ZoomCommand.FromString,
                    response_serializer=camera__reachy__pb2.ZoomCommandAck.SerializeToString,
            ),
            'GetZoomFocus': grpc.unary_unary_rpc_method_handler(
                    servicer.GetZoomFocus,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=camera__reachy__pb2.ZoomFocusMessage.SerializeToString,
            ),
            'SetZoomFocus': grpc.unary_unary_rpc_method_handler(
                    servicer.SetZoomFocus,
                    request_deserializer=camera__reachy__pb2.ZoomFocusMessage.FromString,
                    response_serializer=camera__reachy__pb2.ZoomCommandAck.SerializeToString,
            ),
            'StartAutofocus': grpc.unary_unary_rpc_method_handler(
                    servicer.StartAutofocus,
                    request_deserializer=camera__reachy__pb2.Camera.FromString,
                    response_serializer=camera__reachy__pb2.ZoomCommandAck.SerializeToString,
            ),
            'StopAutofocus': grpc.unary_unary_rpc_method_handler(
                    servicer.StopAutofocus,
                    request_deserializer=camera__reachy__pb2.Camera.FromString,
                    response_serializer=camera__reachy__pb2.ZoomCommandAck.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'reachy.sdk.camera.CameraService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class CameraService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetImage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/reachy.sdk.camera.CameraService/GetImage',
            camera__reachy__pb2.ImageRequest.SerializeToString,
            camera__reachy__pb2.Image.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StreamImage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/reachy.sdk.camera.CameraService/StreamImage',
            camera__reachy__pb2.StreamImageRequest.SerializeToString,
            camera__reachy__pb2.Image.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetZoomLevel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/reachy.sdk.camera.CameraService/GetZoomLevel',
            camera__reachy__pb2.Camera.SerializeToString,
            camera__reachy__pb2.ZoomLevel.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetZoomSpeed(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/reachy.sdk.camera.CameraService/GetZoomSpeed',
            camera__reachy__pb2.Camera.SerializeToString,
            camera__reachy__pb2.ZoomSpeed.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SendZoomCommand(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/reachy.sdk.camera.CameraService/SendZoomCommand',
            camera__reachy__pb2.ZoomCommand.SerializeToString,
            camera__reachy__pb2.ZoomCommandAck.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetZoomFocus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/reachy.sdk.camera.CameraService/GetZoomFocus',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            camera__reachy__pb2.ZoomFocusMessage.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetZoomFocus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/reachy.sdk.camera.CameraService/SetZoomFocus',
            camera__reachy__pb2.ZoomFocusMessage.SerializeToString,
            camera__reachy__pb2.ZoomCommandAck.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StartAutofocus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/reachy.sdk.camera.CameraService/StartAutofocus',
            camera__reachy__pb2.Camera.SerializeToString,
            camera__reachy__pb2.ZoomCommandAck.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StopAutofocus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/reachy.sdk.camera.CameraService/StopAutofocus',
            camera__reachy__pb2.Camera.SerializeToString,
            camera__reachy__pb2.ZoomCommandAck.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: camera_reachy.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13\x63\x61mera_reachy.proto\x12\x11reachy.sdk.camera\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1bgoogle/protobuf/empty.proto\"\x15\n\x05Image\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\"1\n\x06\x43\x61mera\x12\'\n\x02id\x18\x01 \x01(\x0e\x32\x1b.reachy.sdk.camera.CameraId\"3\n\x07\x43\x61meras\x12(\n\x03ids\x18\x01 \x03(\x0e\x32\x1b.reachy.sdk.camera.CameraId\"9\n\x0cImageRequest\x12)\n\x06\x63\x61mera\x18\x01 \x01(\x0b\x32\x19.reachy.sdk.camera.Camera\"F\n\x12StreamImageRequest\x12\x30\n\x07request\x18\x01 \x01(\x0b\x32\x1f.reachy.sdk.camera.ImageRequest\"\x1a\n\tZoomSpeed\x12\r\n\x05speed\x18\x01 \x01(\r\"\x0c\n\nZoomHoming\"E\n\tZoomLevel\x12\x38\n\x05level\x18\x01 \x01(\x0e\x32).reachy.sdk.camera.ZoomLevelPossibilities\"!\n\x0eZoomCommandAck\x12\x0f\n\x07success\x18\x01 \x01(\x08\"\xea\x01\n\x0bZoomCommand\x12)\n\x06\x63\x61mera\x18\x01 \x01(\x0b\x32\x19.reachy.sdk.camera.Camera\x12\x37\n\x0ehoming_command\x18\x02 \x01(\x0b\x32\x1d.reachy.sdk.camera.ZoomHomingH\x00\x12\x35\n\rspeed_command\x18\x03 \x01(\x0b\x32\x1c.reachy.sdk.camera.ZoomSpeedH\x00\x12\x35\n\rlevel_command\x18\x04 \x01(\x0b\x32\x1c.reachy.sdk.camera.ZoomLevelH\x00\x42\t\n\x07\x63ommand\"\xda\x01\n\x10ZoomFocusMessage\x12\x30\n\nleft_focus\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12/\n\tleft_zoom\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x31\n\x0bright_focus\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x30\n\nright_zoom\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value*\x1f\n\x08\x43\x61meraId\x12\x08\n\x04LEFT\x10\x00\x12\t\n\x05RIGHT\x10\x01*>\n\x16ZoomLevelPossibilities\x12\x08\n\x04ZERO\x10\x00\x12\x06\n\x02IN\x10\x01\x12\t\n\x05INTER\x10\x02\x12\x07\n\x03OUT\x10\x03\x32\xd4\x05\n\rCameraService\x12\x45\n\x08GetImage\x12\x1f.reachy.sdk.camera.ImageRequest\x1a\x18.reachy.sdk.camera.Image\x12P\n\x0bStreamImage\x12%.reachy.sdk.camera.StreamImageRequest\x1a\x18.reachy.sdk.camera.Image0\x01\x12G\n\x0cGetZoomLevel\x12\x19.reachy.sdk.camera.Camera\x1a\x1c.reachy.sdk.camera.ZoomLevel\x12G\n\x0cGetZoomSpeed\x12\x19.reachy.sdk.camera.Camera\x1a\x1c.reachy.sdk.camera.ZoomSpeed\x12T\n\x0fSendZoomCommand\x12\x1e.reachy.sdk.camera.ZoomCommand\x1a!.reachy.sdk.camera.ZoomCommandAck\x12K\n\x0cGetZoomFocus\x12\x16.google.protobuf.Empty\x1a#.reachy.sdk.camera.ZoomFocusMessage\x12V\n\x0cSetZoomFocus\x12#.reachy.sdk.camera.ZoomFocusMessage\x1a!.reachy.sdk.camera.ZoomCommandAck\x12N\n\x0eStartAutofocus\x12\x19.reachy.sdk.camera.Camera\x1a!.reachy.sdk.camera.ZoomCommandAck\x12M\n\rStopAutofocus\x12\x19.reachy.sdk.camera.Camera\x1a!.reachy.sdk.camera.ZoomCommandAckb\x06proto3')

_CAMERAID = DESCRIPTOR.enum_types_by_name['CameraId']
CameraId = enum_type_wrapper.EnumTypeWrapper(_CAMERAID)
_ZOOMLEVELPOSSIBILITIES = DESCRIPTOR.enum_types_by_name['ZoomLevelPossibilities']
ZoomLevelPossibilities = enum_type_wrapper.EnumTypeWrapper(_ZOOMLEVELPOSSIBILITIES)
LEFT = 0
RIGHT = 1
ZERO = 0
IN = 1
INTER = 2
OUT = 3


_IMAGE = DESCRIPTOR.message_types_by_name['Image']
_CAMERA = DESCRIPTOR.message_types_by_name['Camera']
_CAMERAS = DESCRIPTOR.message_types_by_name['Cameras']
_IMAGEREQUEST = DESCRIPTOR.message_types_by_name['ImageRequest']
_STREAMIMAGEREQUEST = DESCRIPTOR.message_types_by_name['StreamImageRequest']
_ZOOMSPEED = DESCRIPTOR.message_types_by_name['ZoomSpeed']
_ZOOMHOMING = DESCRIPTOR.message_types_by_name['ZoomHoming']
_ZOOMLEVEL = DESCRIPTOR.message_types_by_name['ZoomLevel']
_ZOOMCOMMANDACK = DESCRIPTOR.message_types_by_name['ZoomCommandAck']
_ZOOMCOMMAND = DESCRIPTOR.message_types_by_name['ZoomCommand']
_ZOOMFOCUSMESSAGE = DESCRIPTOR.message_types_by_name['ZoomFocusMessage']
Image = _reflection.GeneratedProtocolMessageType('Image', (_message.Message,), {
  'DESCRIPTOR' : _IMAGE,
  '__module__' : 'camera_reachy_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.camera.Image)
  })
_sym_db.RegisterMessage(Image)

Camera = _reflection.GeneratedProtocolMessageType('Camera', (_message.Message,), {
  'DESCRIPTOR' : _CAMERA,
  '__module__' : 'camera_reachy_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.camera.Camera)
  })
_sym_db.RegisterMessage(Camera)

Cameras = _reflection.GeneratedProtocolMessageType('Cameras', (_message.Message,), {
  'DESCRIPTOR' : _CAMERAS,
  '__module__' : 'camera_reachy_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.camera.Cameras)
  })
_sym_db.RegisterMessage(Cameras)

ImageRequest = _reflection.GeneratedProtocolMessageType('ImageRequest', (_message.Message,), {
  'DESCRIPTOR' : _IMAGEREQUEST,
  '__module__' : 'camera_reachy_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.camera.ImageRequest)
  })
_sym_db.RegisterMessage(ImageRequest)

StreamImageRequest = _reflection.GeneratedProtocolMessageType('StreamImageRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMIMAGEREQUEST,
  '__module__' : 'camera_reachy_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.camera.StreamImageRequest)
  })
_sym_db.RegisterMessage(StreamImageRequest)

ZoomSpeed = _reflection.GeneratedProtocolMessageType('ZoomSpeed', (_message.Message,), {
  'DESCRIPTOR' : _ZOOMSPEED,
  '__module__' : 'camera_reachy_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.camera.ZoomSpeed)
  })
_sym_db.RegisterMessage(ZoomSpeed)

ZoomHoming = _reflection.GeneratedProtocolMessageType('ZoomHoming', (_message.Message,), {
  'DESCRIPTOR' : _ZOOMHOMING,
  '__module__' : 'camera_reachy_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.camera.ZoomHoming)
  })
_sym_db.RegisterMessage(ZoomHoming)

ZoomLevel = _reflection.GeneratedProtocolMessageType('ZoomLevel', (_message.Message,), {
  'DESCRIPTOR' : _ZOOMLEVEL,
  '__module__' : 'camera_reachy_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.camera.ZoomLevel)
  })
_sym_db.RegisterMessage(ZoomLevel)

ZoomCommandAck = _reflection.GeneratedProtocolMessageType('ZoomCommandAck', (_message.Message,), {
  'DESCRIPTOR' : _ZOOMCOMMANDACK,
  '__module__' : 'camera_reachy_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.camera.ZoomCommandAck)
  })
_sym_db.RegisterMessage(ZoomCommandAck)

ZoomCommand = _reflection.GeneratedProtocolMessageType('ZoomCommand', (_message.Message,), {
  'DESCRIPTOR' : _ZOOMCOMMAND,
  '__module__' : 'camera_reachy_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.camera.ZoomCommand)
  })
_sym_db.RegisterMessage(ZoomCommand)

ZoomFocusMessage = _reflection.GeneratedProtocolMessageType('ZoomFocusMessage', (_message.Message,), {
  'DESCRIPTOR' : _ZOOMFOCUSMESSAGE,
  '__module__' : 'camera_reachy_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.camera.ZoomFocusMessage)
  })
_sym_db.RegisterMessage(ZoomFocusMessage)

_CAMERASERVICE = DESCRIPTOR.services_by_name['CameraService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CAMERAID._serialized_start=967
  _CAMERAID._serialized_end=998
  _ZOOMLEVELPOSSIBILITIES._serialized_start=1000
  _ZOOMLEVELPOSSIBILITIES._serialized_end=1062
  _IMAGE._serialized_start=103
  _IMAGE._serialized_end=124
  _CAMERA._serialized_start=126
  _CAMERA._serialized_end=175
  _CAMERAS._serialized_start=177
  _CAMERAS._serialized_end=228
  _IMAGEREQUEST._serialized_start=230
  _IMAGEREQUEST._serialized_end=287
  _STREAMIMAGEREQUEST._serialized_start=289
  _STREAMIMAGEREQUEST._serialized_end=359
  _ZOOMSPEED._serialized_start=361
  _ZOOMSPEED._serialized_end=387
  _ZOOMHOMING._serialized_start=389
  _ZOOMHOMING._serialized_end=401
  _ZOOMLEVEL._serialized_start=403
  _ZOOMLEVEL._serialized_end=472
  _ZOOMCOMMANDACK._serialized_start=474
  _ZOOMCOMMANDACK._serialized_end=507
  _ZOOMCOMMAND._serialized_start=510
  _ZOOMCOMMAND._serialized_end=744
  _ZOOMFOCUSMESSAGE._serialized_start=747
  _ZOOMFOCUSMESSAGE._serialized_end=965
  _CAMERASERVICE._serialized_start=1065
  _CAMERASERVICE._serialized_end=1789
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
import joint_pb2 as joint__pb2


class JointServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetAllJointsId = channel.unary_unary(
                '/reachy.sdk.joint.JointService/GetAllJointsId',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=joint__pb2.JointsId.FromString,
                )
        self.GetJointsState = channel.unary_unary(
                '/reachy.sdk.joint.JointService/GetJointsState',
                request_serializer=joint__pb2.JointsStateRequest.SerializeToString,
                response_deserializer=joint__pb2.JointsState.FromString,
                )
        self.StreamJointsState = channel.unary_stream(
                '/reachy.sdk.joint.JointService/StreamJointsState',
                request_serializer=joint__pb2.StreamJointsRequest.SerializeToString,
                response_deserializer=joint__pb2.JointsState.FromString,
                )
        self.SendJointsCommands = channel.unary_unary(
                '/reachy.sdk.joint.JointService/SendJointsCommands',
                request_serializer=joint__pb2.JointsCommand.SerializeToString,
                response_deserializer=joint__pb2.JointsCommandAck.FromString,
                )
        self.StreamJointsCommands = channel.stream_unary(
                '/reachy.sdk.joint.JointService/StreamJointsCommands',
                request_serializer=joint__pb2.JointsCommand.SerializeToString,
                response_deserializer=joint__pb2.JointsCommandAck.FromString,
                )


class JointServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetAllJointsId(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetJointsState(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StreamJointsState(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SendJointsCommands(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StreamJointsCommands(self, request_iterator, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_JointServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetAllJointsId': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAllJointsId,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=joint__pb2.JointsId.SerializeToString,
            ),
            'GetJointsState': grpc.unary_unary_rpc_method_handler(
                    servicer.GetJointsState,
                    request_deserializer=joint__pb2.JointsStateRequest.FromString,
                    response_serializer=joint__pb2.JointsState.SerializeToString,
            ),
            'StreamJointsState': grpc.unary_stream_rpc_method_handler(
                    servicer.StreamJointsState,
                    request_deserializer=joint__pb2.StreamJointsRequest.FromString,
                    response_serializer=joint__pb2.JointsState.SerializeToString,
            ),
            'SendJointsCommands': grpc.unary_unary_rpc_method_handler(
                    servicer.SendJointsCommands,
                    request_deserializer=joint__pb2.JointsCommand.FromString,
                    response_serializer=joint__pb2.JointsCommandAck.SerializeToString,
            ),
            'StreamJointsCommands': grpc.stream_unary_rpc_method_handler(
                    servicer.StreamJointsCommands,
                    request_deserializer=joint__pb2.JointsCommand.FromString,
                    response_serializer=joint__pb2.JointsCommandAck.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'reachy.sdk.joint.JointService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class JointService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetAllJointsId(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/reachy.sdk.joint.JointService/GetAllJointsId',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            joint__pb2.JointsId.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetJointsState(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/reachy.sdk.joint.JointService/GetJointsState',
            joint__pb2.JointsStateRequest.SerializeToString,
            joint__pb2.JointsState.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StreamJointsState(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/reachy.sdk.joint.JointService/StreamJointsState',
            joint__pb2.StreamJointsRequest.SerializeToString,
            joint__pb2.JointsState.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SendJointsCommands(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/reachy.sdk.joint.JointService/SendJointsCommands',
            joint__pb2.JointsCommand.SerializeToString,
            joint__pb2.JointsCommandAck.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StreamJointsCommands(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_unary(request_iterator, target, '/reachy.sdk.joint.JointService/StreamJointsCommands',
            joint__pb2.JointsCommand.SerializeToString,
            joint__pb2.JointsCommandAck.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: head_kinematics.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import kinematics_pb2 as kinematics__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15head_kinematics.proto\x12\x15reachy.sdk.kinematics\x1a\x10kinematics.proto\"o\n\rHeadIKRequest\x12,\n\x01q\x18\x01 \x01(\x0b\x32!.reachy.sdk.kinematics.Quaternion\x12\x30\n\x02q0\x18\x02 \x01(\x0b\x32$.reachy.sdk.kinematics.JointPosition\"L\n\rHeadFKRequest\x12;\n\rneck_position\x18\x01 \x01(\x0b\x32$.reachy.sdk.kinematics.JointPosition\"O\n\x0eHeadFKSolution\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12,\n\x01q\x18\x02 \x01(\x0b\x32!.reachy.sdk.kinematics.Quaternion\"^\n\x0eHeadIKSolution\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12;\n\rneck_position\x18\x02 \x01(\x0b\x32$.reachy.sdk.kinematics.JointPosition2\xcc\x01\n\x0eHeadKinematics\x12\\\n\rComputeHeadFK\x12$.reachy.sdk.kinematics.HeadFKRequest\x1a%.reachy.sdk.kinematics.HeadFKSolution\x12\\\n\rComputeHeadIK\x12$.reachy.sdk.kinematics.HeadIKRequest\x1a%.reachy.sdk.kinematics.HeadIKSolutionb\x06proto3')



_HEADIKREQUEST = DESCRIPTOR.message_types_by_name['HeadIKRequest']
_HEADFKREQUEST = DESCRIPTOR.message_types_by_name['HeadFKRequest']
_HEADFKSOLUTION = DESCRIPTOR.message_types_by_name['HeadFKSolution']
_HEADIKSOLUTION = DESCRIPTOR.message_types_by_name['HeadIKSolution']
HeadIKRequest = _reflection.GeneratedProtocolMessageType('HeadIKRequest', (_message.Message,), {
  'DESCRIPTOR' : _HEADIKREQUEST,
  '__module__' : 'head_kinematics_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.kinematics.HeadIKRequest)
  })
_sym_db.RegisterMessage(HeadIKRequest)

HeadFKRequest = _reflection.GeneratedProtocolMessageType('HeadFKRequest', (_message.Message,), {
  'DESCRIPTOR' : _HEADFKREQUEST,
  '__module__' : 'head_kinematics_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.kinematics.HeadFKRequest)
  })
_sym_db.RegisterMessage(HeadFKRequest)

HeadFKSolution = _reflection.GeneratedProtocolMessageType('HeadFKSolution', (_message.Message,), {
  'DESCRIPTOR' : _HEADFKSOLUTION,
  '__module__' : 'head_kinematics_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.kinematics.HeadFKSolution)
  })
_sym_db.RegisterMessage(HeadFKSolution)

HeadIKSolution = _reflection.GeneratedProtocolMessageType('HeadIKSolution', (_message.Message,), {
  'DESCRIPTOR' : _HEADIKSOLUTION,
  '__module__' : 'head_kinematics_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.kinematics.HeadIKSolution)
  })
_sym_db.RegisterMessage(HeadIKSolution)

_HEADKINEMATICS = DESCRIPTOR.services_by_name['HeadKinematics']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _HEADIKREQUEST._serialized_start=66
  _HEADIKREQUEST._serialized_end=177
  _HEADFKREQUEST._serialized_start=179
  _HEADFKREQUEST._serialized_end=255
  _HEADFKSOLUTION._serialized_start=257
  _HEADFKSOLUTION._serialized_end=336
  _HEADIKSOLUTION._serialized_start=338
  _HEADIKSOLUTION._serialized_end=432
  _HEADKINEMATICS._serialized_start=435
  _HEADKINEMATICS._serialized_end=639
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sensor.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0csensor.proto\x12\x10reachy.sdk.joint\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1bgoogle/protobuf/empty.proto\"/\n\x08SensorId\x12\x0e\n\x04name\x18\x01 \x01(\tH\x00\x12\r\n\x03uid\x18\x02 \x01(\rH\x00\x42\x04\n\x02id\"(\n\tSensorsId\x12\r\n\x05names\x18\x01 \x03(\t\x12\x0c\n\x04uids\x18\x02 \x03(\r\"!\n\x10\x46orceSensorState\x12\r\n\x05\x66orce\x18\x01 \x01(\x02\"X\n\x0bSensorState\x12@\n\x12\x66orce_sensor_state\x18\x01 \x01(\x0b\x32\".reachy.sdk.joint.ForceSensorStateH\x00\x42\x07\n\x05state\"\x95\x01\n\x0cSensorsState\x12\'\n\x03ids\x18\x01 \x03(\x0b\x32\x1a.reachy.sdk.joint.SensorId\x12-\n\x06states\x18\x02 \x03(\x0b\x32\x1d.reachy.sdk.joint.SensorState\x12-\n\ttimestamp\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"m\n\x13SensorsStateRequest\x12\'\n\x03ids\x18\x01 \x03(\x0b\x32\x1a.reachy.sdk.joint.SensorId\x12-\n\ttimestamp\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"n\n\x19StreamSensorsStateRequest\x12\x36\n\x07request\x18\x01 \x01(\x0b\x32%.reachy.sdk.joint.SensorsStateRequest\x12\x19\n\x11publish_frequency\x18\x02 \x01(\x02\x32\x9b\x02\n\rSensorService\x12K\n\x14GetAllForceSensorsId\x12\x16.google.protobuf.Empty\x1a\x1b.reachy.sdk.joint.SensorsId\x12X\n\x0fGetSensorsState\x12%.reachy.sdk.joint.SensorsStateRequest\x1a\x1e.reachy.sdk.joint.SensorsState\x12\x63\n\x12StreamSensorStates\x12+.reachy.sdk.joint.StreamSensorsStateRequest\x1a\x1e.reachy.sdk.joint.SensorsState0\x01\x62\x06proto3')



_SENSORID = DESCRIPTOR.message_types_by_name['SensorId']
_SENSORSID = DESCRIPTOR.message_types_by_name['SensorsId']
_FORCESENSORSTATE = DESCRIPTOR.message_types_by_name['ForceSensorState']
_SENSORSTATE = DESCRIPTOR.message_types_by_name['SensorState']
_SENSORSSTATE = DESCRIPTOR.message_types_by_name['SensorsState']
_SENSORSSTATEREQUEST = DESCRIPTOR.message_types_by_name['SensorsStateRequest']
_STREAMSENSORSSTATEREQUEST = DESCRIPTOR.message_types_by_name['StreamSensorsStateRequest']
SensorId = _reflection.GeneratedProtocolMessageType('SensorId', (_message.Message,), {
  'DESCRIPTOR' : _SENSORID,
  '__module__' : 'sensor_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.joint.SensorId)
  })
_sym_db.RegisterMessage(SensorId)

SensorsId = _reflection.GeneratedProtocolMessageType('SensorsId', (_message.Message,), {
  'DESCRIPTOR' : _SENSORSID,
  '__module__' : 'sensor_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.joint.SensorsId)
  })
_sym_db.RegisterMessage(SensorsId)

ForceSensorState = _reflection.GeneratedProtocolMessageType('ForceSensorState', (_message.Message,), {
  'DESCRIPTOR' : _FORCESENSORSTATE,
  '__module__' : 'sensor_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.joint.ForceSensorState)
  })
_sym_db.RegisterMessage(ForceSensorState)

SensorState = _reflection.GeneratedProtocolMessageType('SensorState', (_message.Message,), {
  'DESCRIPTOR' : _SENSORSTATE,
  '__module__' : 'sensor_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.joint.SensorState)
  })
_sym_db.RegisterMessage(SensorState)

SensorsState = _reflection.GeneratedProtocolMessageType('SensorsState', (_message.Message,), {
  'DESCRIPTOR' : _SENSORSSTATE,
  '__module__' : 'sensor_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.joint.SensorsState)
  })
_sym_db.RegisterMessage(SensorsState)

SensorsStateRequest = _reflection.GeneratedProtocolMessageType('SensorsStateRequest', (_message.Message,), {
  'DESCRIPTOR' : _SENSORSSTATEREQUEST,
  '__module__' : 'sensor_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.joint.SensorsStateRequest)
  })
_sym_db.RegisterMessage(SensorsStateRequest)

StreamSensorsStateRequest = _reflection.GeneratedProtocolMessageType('StreamSensorsStateRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMSENSORSSTATEREQUEST,
  '__module__' : 'sensor_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.joint.StreamSensorsStateRequest)
  })
_sym_db.RegisterMessage(StreamSensorsStateRequest)

_SENSORSERVICE = DESCRIPTOR.services_by_name['SensorService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SENSORID._serialized_start=96
  _SENSORID._serialized_end=143
  _SENSORSID._serialized_start=145
  _SENSORSID._serialized_end=185
  _FORCESENSORSTATE._serialized_start=187
  _FORCESENSORSTATE._serialized_end=220
  _SENSORSTATE._serialized_start=222
  _SENSORSTATE._serialized_end=310
  _SENSORSSTATE._serialized_start=313
  _SENSORSSTATE._serialized_end=462
  _SENSORSSTATEREQUEST._serialized_start=464
  _SENSORSSTATEREQUEST._serialized_end=573
  _STREAMSENSORSSTATEREQUEST._serialized_start=575
  _STREAMSENSORSSTATEREQUEST._serialized_end=685
  _SENSORSERVICE._serialized_start=688
  _SENSORSERVICE._serialized_end=971
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: exo_arm.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rexo_arm.proto\x12\x12reachy.sdk.exo_arm\x1a\x1egoogle/protobuf/wrappers.proto\"e\n\x0c\x45lbowTorques\x12*\n\x05right\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12)\n\x04left\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int32Valueb\x06proto3')



_ELBOWTORQUES = DESCRIPTOR.message_types_by_name['ElbowTorques']
ElbowTorques = _reflection.GeneratedProtocolMessageType('ElbowTorques', (_message.Message,), {
  'DESCRIPTOR' : _ELBOWTORQUES,
  '__module__' : 'exo_arm_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.exo_arm.ElbowTorques)
  })
_sym_db.RegisterMessage(ElbowTorques)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ELBOWTORQUES._serialized_start=69
  _ELBOWTORQUES._serialized_end=170
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: any_joint_command.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
import fullbody_cartesian_command_pb2 as fullbody__cartesian__command__pb2
import joint_pb2 as joint__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17\x61ny_joint_command.proto\x12\x10reachy.sdk.joint\x1a\x1fgoogle/protobuf/timestamp.proto\x1a fullbody_cartesian_command.proto\x1a\x0bjoint.proto\"\xc5\x01\n\x10\x41nyJointsCommand\x12\x44\n\tfull_body\x18\x01 \x01(\x0b\x32/.reachy.sdk.kinematics.FullBodyCartesianCommandH\x00\x12\x31\n\x06joints\x18\x03 \x01(\x0b\x32\x1f.reachy.sdk.joint.JointsCommandH\x00\x12-\n\ttimestamp\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.TimestampB\t\n\x07\x63ommandb\x06proto3')



_ANYJOINTSCOMMAND = DESCRIPTOR.message_types_by_name['AnyJointsCommand']
AnyJointsCommand = _reflection.GeneratedProtocolMessageType('AnyJointsCommand', (_message.Message,), {
  'DESCRIPTOR' : _ANYJOINTSCOMMAND,
  '__module__' : 'any_joint_command_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.joint.AnyJointsCommand)
  })
_sym_db.RegisterMessage(AnyJointsCommand)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ANYJOINTSCOMMAND._serialized_start=126
  _ANYJOINTSCOMMAND._serialized_end=323
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: realsense.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0frealsense.proto\x12\x14reachy.sdk.realsense\x1a\x1egoogle/protobuf/wrappers.proto\"\x7f\n\x05Point\x12&\n\x01x\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\x12&\n\x01y\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\x12&\n\x01z\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\">\n\nPointCloud\x12\x30\n\x0bpoint_cloud\x18\x04 \x03(\x0b\x32\x1b.reachy.sdk.realsense.Point\"x\n\x11PointCloudMessage\x12\x30\n\x06ground\x18\x05 \x01(\x0b\x32 .reachy.sdk.realsense.PointCloud\x12\x31\n\x07objects\x18\x06 \x01(\x0b\x32 .reachy.sdk.realsense.PointCloudb\x06proto3')



_POINT = DESCRIPTOR.message_types_by_name['Point']
_POINTCLOUD = DESCRIPTOR.message_types_by_name['PointCloud']
_POINTCLOUDMESSAGE = DESCRIPTOR.message_types_by_name['PointCloudMessage']
Point = _reflection.GeneratedProtocolMessageType('Point', (_message.Message,), {
  'DESCRIPTOR' : _POINT,
  '__module__' : 'realsense_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.realsense.Point)
  })
_sym_db.RegisterMessage(Point)

PointCloud = _reflection.GeneratedProtocolMessageType('PointCloud', (_message.Message,), {
  'DESCRIPTOR' : _POINTCLOUD,
  '__module__' : 'realsense_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.realsense.PointCloud)
  })
_sym_db.RegisterMessage(PointCloud)

PointCloudMessage = _reflection.GeneratedProtocolMessageType('PointCloudMessage', (_message.Message,), {
  'DESCRIPTOR' : _POINTCLOUDMESSAGE,
  '__module__' : 'realsense_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.realsense.PointCloudMessage)
  })
_sym_db.RegisterMessage(PointCloudMessage)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _POINT._serialized_start=73
  _POINT._serialized_end=200
  _POINTCLOUD._serialized_start=202
  _POINTCLOUD._serialized_end=264
  _POINTCLOUDMESSAGE._serialized_start=266
  _POINTCLOUDMESSAGE._serialized_end=386
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
import mobile_platform_reachy_pb2 as mobile__platform__reachy__pb2


class MobilityServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.SendDirection = channel.unary_unary(
                '/reachy.sdk.mobility.MobilityService/SendDirection',
                request_serializer=mobile__platform__reachy__pb2.TargetDirectionCommand.SerializeToString,
                response_deserializer=mobile__platform__reachy__pb2.MobilityServiceAck.FromString,
                )
        self.SendSetSpeed = channel.unary_unary(
                '/reachy.sdk.mobility.MobilityService/SendSetSpeed',
                request_serializer=mobile__platform__reachy__pb2.SetSpeedVector.SerializeToString,
                response_deserializer=mobile__platform__reachy__pb2.MobilityServiceAck.FromString,
                )
        self.SendGoTo = channel.unary_unary(
                '/reachy.sdk.mobility.MobilityService/SendGoTo',
                request_serializer=mobile__platform__reachy__pb2.GoToVector.SerializeToString,
                response_deserializer=mobile__platform__reachy__pb2.MobilityServiceAck.FromString,
                )
        self.DistanceToGoal = channel.unary_unary(
                '/reachy.sdk.mobility.MobilityService/DistanceToGoal',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=mobile__platform__reachy__pb2.DistanceToGoalVector.FromString,
                )
        self.SetControlMode = channel.unary_unary(
                '/reachy.sdk.mobility.MobilityService/SetControlMode',
                request_serializer=mobile__platform__reachy__pb2.ControlModeCommand.SerializeToString,
                response_deserializer=mobile__platform__reachy__pb2.MobilityServiceAck.FromString,
                )
        self.GetControlMode = channel.unary_unary(
                '/reachy.sdk.mobility.MobilityService/GetControlMode',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=mobile__platform__reachy__pb2.ControlModeCommand.FromString,
                )
        self.SetZuuuMode = channel.unary_unary(
                '/reachy.sdk.mobility.MobilityService/SetZuuuMode',
                request_serializer=mobile__platform__reachy__pb2.ZuuuModeCommand.SerializeToString,
                response_deserializer=mobile__platform__reachy__pb2.MobilityServiceAck.FromString,
                )
        self.GetZuuuMode = channel.unary_unary(
                '/reachy.sdk.mobility.MobilityService/GetZuuuMode',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=mobile__platform__reachy__pb2.ZuuuModeCommand.FromString,
                )
        self.GetBatteryLevel = channel.unary_unary(
                '/reachy.sdk.mobility.MobilityService/GetBatteryLevel',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=mobile__platform__reachy__pb2.BatteryLevel.FromString,
                )
        self.GetOdometry = channel.unary_unary(
                '/reachy.sdk.mobility.MobilityService/GetOdometry',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=mobile__platform__reachy__pb2.OdometryVector.FromString,
                )
        self.ResetOdometry = channel.unary_unary(
                '/reachy.sdk.mobility.MobilityService/ResetOdometry',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=mobile__platform__reachy__pb2.MobilityServiceAck.FromString,
                )
        self.SetZuuuSafety = channel.unary_unary(
                '/reachy.sdk.mobility.MobilityService/SetZuuuSafety',
                request_serializer=mobile__platform__reachy__pb2.SetZuuuSafetyRequest.SerializeToString,
                response_deserializer=mobile__platform__reachy__pb2.MobilityServiceAck.FromString,
                )


class MobilityServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def SendDirection(self, request, context):
        """Mobility commands
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SendSetSpeed(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SendGoTo(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DistanceToGoal(self, request, context):
        """GoTo management
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetControlMode(self, request, context):
        """Utility
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetControlMode(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetZuuuMode(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetZuuuMode(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBatteryLevel(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetOdometry(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ResetOdometry(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetZuuuSafety(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MobilityServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'SendDirection': grpc.unary_unary_rpc_method_handler(
                    servicer.SendDirection,
                    request_deserializer=mobile__platform__reachy__pb2.TargetDirectionCommand.FromString,
                    response_serializer=mobile__platform__reachy__pb2.MobilityServiceAck.SerializeToString,
            ),
            'SendSetSpeed': grpc.unary_unary_rpc_method_handler(
                    servicer.SendSetSpeed,
                    request_deserializer=mobile__platform__reachy__pb2.SetSpeedVector.FromString,
                    response_serializer=mobile__platform__reachy__pb2.MobilityServiceAck.SerializeToString,
            ),
            'SendGoTo': grpc.unary_unary_rpc_method_handler(
                    servicer.SendGoTo,
                    request_deserializer=mobile__platform__reachy__pb2.GoToVector.FromString,
                    response_serializer=mobile__platform__reachy__pb2.MobilityServiceAck.SerializeToString,
            ),
            'DistanceToGoal': grpc.unary_unary_rpc_method_handler(
                    servicer.DistanceToGoal,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=mobile__platform__reachy__pb2.DistanceToGoalVector.SerializeToString,
            ),
            'SetControlMode': grpc.unary_unary_rpc_method_handler(
                    servicer.SetControlMode,
                    request_deserializer=mobile__platform__reachy__pb2.ControlModeCommand.FromString,
                    response_serializer=mobile__platform__reachy__pb2.MobilityServiceAck.SerializeToString,
            ),
            'GetControlMode': grpc.unary_unary_rpc_method_handler(
                    servicer.GetControlMode,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=mobile__platform__reachy__pb2.ControlModeCommand.SerializeToString,
            ),
            'SetZuuuMode': grpc.unary_unary_rpc_method_handler(
                    servicer.SetZuuuMode,
                    request_deserializer=mobile__platform__reachy__pb2.ZuuuModeCommand.FromString,
                    response_serializer=mobile__platform__reachy__pb2.MobilityServiceAck.SerializeToString,
            ),
            'GetZuuuMode': grpc.unary_unary_rpc_method_handler(
                    servicer.GetZuuuMode,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=mobile__platform__reachy__pb2.ZuuuModeCommand.SerializeToString,
            ),
            'GetBatteryLevel': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBatteryLevel,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=mobile__platform__reachy__pb2.BatteryLevel.SerializeToString,
            ),
            'GetOdometry': grpc.unary_unary_rpc_method_handler(
                    servicer.GetOdometry,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=mobile__platform__reachy__pb2.OdometryVector.SerializeToString,
            ),
            'ResetOdometry': grpc.unary_unary_rpc_method_handler(
                    servicer.ResetOdometry,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=mobile__platform__reachy__pb2.MobilityServiceAck.SerializeToString,
            ),
            'SetZuuuSafety': grpc.unary_unary_rpc_method_handler(
                    servicer.SetZuuuSafety,
                    request_deserializer=mobile__platform__reachy__pb2.SetZuuuSafetyRequest.FromString,
                    response_serializer=mobile__platform__reachy__pb2.MobilityServiceAck.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'reachy.sdk.mobility.MobilityService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class MobilityService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def SendDirection(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/reachy.sdk.mobility.MobilityService/SendDirection',
            mobile__platform__reachy__pb2.TargetDirectionCommand.SerializeToString,
            mobile__platform__reachy__pb2.MobilityServiceAck.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SendSetSpeed(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/reachy.sdk.mobility.MobilityService/SendSetSpeed',
            mobile__platform__reachy__pb2.SetSpeedVector.SerializeToString,
            mobile__platform__reachy__pb2.MobilityServiceAck.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SendGoTo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/reachy.sdk.mobility.MobilityService/SendGoTo',
            mobile__platform__reachy__pb2.GoToVector.SerializeToString,
            mobile__platform__reachy__pb2.MobilityServiceAck.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DistanceToGoal(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/reachy.sdk.mobility.MobilityService/DistanceToGoal',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            mobile__platform__reachy__pb2.DistanceToGoalVector.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetControlMode(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/reachy.sdk.mobility.MobilityService/SetControlMode',
            mobile__platform__reachy__pb2.ControlModeCommand.SerializeToString,
            mobile__platform__reachy__pb2.MobilityServiceAck.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetControlMode(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/reachy.sdk.mobility.MobilityService/GetControlMode',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            mobile__platform__reachy__pb2.ControlModeCommand.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetZuuuMode(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/reachy.sdk.mobility.MobilityService/SetZuuuMode',
            mobile__platform__reachy__pb2.ZuuuModeCommand.SerializeToString,
            mobile__platform__reachy__pb2.MobilityServiceAck.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetZuuuMode(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/reachy.sdk.mobility.MobilityService/GetZuuuMode',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            mobile__platform__reachy__pb2.ZuuuModeCommand.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetBatteryLevel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/reachy.sdk.mobility.MobilityService/GetBatteryLevel',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            mobile__platform__reachy__pb2.BatteryLevel.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetOdometry(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/reachy.sdk.mobility.MobilityService/GetOdometry',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            mobile__platform__reachy__pb2.OdometryVector.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ResetOdometry(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/reachy.sdk.mobility.MobilityService/ResetOdometry',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            mobile__platform__reachy__pb2.MobilityServiceAck.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetZuuuSafety(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/reachy.sdk.mobility.MobilityService/SetZuuuSafety',
            mobile__platform__reachy__pb2.SetZuuuSafetyRequest.SerializeToString,
            mobile__platform__reachy__pb2.MobilityServiceAck.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)


class MobileBasePresenceServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetMobileBasePresence = channel.unary_unary(
                '/reachy.sdk.mobility.MobileBasePresenceService/GetMobileBasePresence',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=mobile__platform__reachy__pb2.MobileBasePresence.FromString,
                )


class MobileBasePresenceServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetMobileBasePresence(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MobileBasePresenceServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetMobileBasePresence': grpc.unary_unary_rpc_method_handler(
                    servicer.GetMobileBasePresence,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=mobile__platform__reachy__pb2.MobileBasePresence.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'reachy.sdk.mobility.MobileBasePresenceService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class MobileBasePresenceService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetMobileBasePresence(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/reachy.sdk.mobility.MobileBasePresenceService/GetMobileBasePresence',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            mobile__platform__reachy__pb2.MobileBasePresence.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



#!/usr/bin/env python

from os import path
from setuptools import find_packages, setup

here = path.abspath(path.dirname(__file__))

with open(path.join(here, '..', 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='reachy-sdk-api',
    version='0.7.0',
    packages=find_packages(exclude=['tests']),    
    install_requires=[
        'grpcio',
        'grpcio-tools',
        'protobuf>=3.14.0',
    ],    author='Pollen Robotics',
    author_email='contact@pollen-robotics.com',
    url='https://github.com/pollen-robotics/reachy-sdk-api',    description='gRPC Protobuf API definition for Reachy SDK.',
    long_description=long_description,
    long_description_content_type='text/markdown',
)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fullbody_cartesian_command.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import arm_kinematics_pb2 as arm__kinematics__pb2
import head_kinematics_pb2 as head__kinematics__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n fullbody_cartesian_command.proto\x12\x15reachy.sdk.kinematics\x1a\x14\x61rm_kinematics.proto\x1a\x15head_kinematics.proto\"\x80\x01\n\x1b\x46ullBodyCartesianCommandAck\x12 \n\x18left_arm_command_success\x18\x01 \x01(\x08\x12!\n\x19right_arm_command_success\x18\x02 \x01(\x08\x12\x1c\n\x14head_command_success\x18\x03 \x01(\x08\"\xbd\x01\n\x18\x46ullBodyCartesianCommand\x12\x35\n\x08left_arm\x18\x01 \x01(\x0b\x32#.reachy.sdk.kinematics.ArmIKRequest\x12\x36\n\tright_arm\x18\x02 \x01(\x0b\x32#.reachy.sdk.kinematics.ArmIKRequest\x12\x32\n\x04head\x18\x03 \x01(\x0b\x32$.reachy.sdk.kinematics.HeadIKRequest2\xb3\x02\n\x1f\x46ullBodyCartesianCommandService\x12\x84\x01\n\x1dSendFullBodyCartesianCommands\x12/.reachy.sdk.kinematics.FullBodyCartesianCommand\x1a\x32.reachy.sdk.kinematics.FullBodyCartesianCommandAck\x12\x88\x01\n\x1fStreamFullBodyCartesianCommands\x12/.reachy.sdk.kinematics.FullBodyCartesianCommand\x1a\x32.reachy.sdk.kinematics.FullBodyCartesianCommandAck(\x01\x62\x06proto3')



_FULLBODYCARTESIANCOMMANDACK = DESCRIPTOR.message_types_by_name['FullBodyCartesianCommandAck']
_FULLBODYCARTESIANCOMMAND = DESCRIPTOR.message_types_by_name['FullBodyCartesianCommand']
FullBodyCartesianCommandAck = _reflection.GeneratedProtocolMessageType('FullBodyCartesianCommandAck', (_message.Message,), {
  'DESCRIPTOR' : _FULLBODYCARTESIANCOMMANDACK,
  '__module__' : 'fullbody_cartesian_command_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.kinematics.FullBodyCartesianCommandAck)
  })
_sym_db.RegisterMessage(FullBodyCartesianCommandAck)

FullBodyCartesianCommand = _reflection.GeneratedProtocolMessageType('FullBodyCartesianCommand', (_message.Message,), {
  'DESCRIPTOR' : _FULLBODYCARTESIANCOMMAND,
  '__module__' : 'fullbody_cartesian_command_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.kinematics.FullBodyCartesianCommand)
  })
_sym_db.RegisterMessage(FullBodyCartesianCommand)

_FULLBODYCARTESIANCOMMANDSERVICE = DESCRIPTOR.services_by_name['FullBodyCartesianCommandService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _FULLBODYCARTESIANCOMMANDACK._serialized_start=105
  _FULLBODYCARTESIANCOMMANDACK._serialized_end=233
  _FULLBODYCARTESIANCOMMAND._serialized_start=236
  _FULLBODYCARTESIANCOMMAND._serialized_end=425
  _FULLBODYCARTESIANCOMMANDSERVICE._serialized_start=428
  _FULLBODYCARTESIANCOMMANDSERVICE._serialized_end=735
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: restart_signal.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14restart_signal.proto\x12\x12reachy.sdk.restart\"9\n\nRestartCmd\x12+\n\x03\x63md\x18\x01 \x01(\x0e\x32\x1e.reachy.sdk.restart.SignalType\"#\n\x10RestartSignalAck\x12\x0f\n\x07success\x18\x01 \x01(\x08*#\n\nSignalType\x12\x0b\n\x07RESTART\x10\x00\x12\x08\n\x04STOP\x10\x01\x32k\n\x0eRestartService\x12Y\n\x11SendRestartSignal\x12\x1e.reachy.sdk.restart.RestartCmd\x1a$.reachy.sdk.restart.RestartSignalAckb\x06proto3')

_SIGNALTYPE = DESCRIPTOR.enum_types_by_name['SignalType']
SignalType = enum_type_wrapper.EnumTypeWrapper(_SIGNALTYPE)
RESTART = 0
STOP = 1


_RESTARTCMD = DESCRIPTOR.message_types_by_name['RestartCmd']
_RESTARTSIGNALACK = DESCRIPTOR.message_types_by_name['RestartSignalAck']
RestartCmd = _reflection.GeneratedProtocolMessageType('RestartCmd', (_message.Message,), {
  'DESCRIPTOR' : _RESTARTCMD,
  '__module__' : 'restart_signal_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.restart.RestartCmd)
  })
_sym_db.RegisterMessage(RestartCmd)

RestartSignalAck = _reflection.GeneratedProtocolMessageType('RestartSignalAck', (_message.Message,), {
  'DESCRIPTOR' : _RESTARTSIGNALACK,
  '__module__' : 'restart_signal_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.restart.RestartSignalAck)
  })
_sym_db.RegisterMessage(RestartSignalAck)

_RESTARTSERVICE = DESCRIPTOR.services_by_name['RestartService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SIGNALTYPE._serialized_start=140
  _SIGNALTYPE._serialized_end=175
  _RESTARTCMD._serialized_start=44
  _RESTARTCMD._serialized_end=101
  _RESTARTSIGNALACK._serialized_start=103
  _RESTARTSIGNALACK._serialized_end=138
  _RESTARTSERVICE._serialized_start=177
  _RESTARTSERVICE._serialized_end=284
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: arm_kinematics.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import kinematics_pb2 as kinematics__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14\x61rm_kinematics.proto\x12\x15reachy.sdk.kinematics\x1a\x10kinematics.proto\"n\n\x0e\x41rmEndEffector\x12,\n\x04side\x18\x01 \x01(\x0e\x32\x1e.reachy.sdk.kinematics.ArmSide\x12.\n\x04pose\x18\x02 \x01(\x0b\x32 .reachy.sdk.kinematics.Matrix4x4\"y\n\x10\x41rmJointPosition\x12,\n\x04side\x18\x01 \x01(\x0e\x32\x1e.reachy.sdk.kinematics.ArmSide\x12\x37\n\tpositions\x18\x02 \x01(\x0b\x32$.reachy.sdk.kinematics.JointPosition\"M\n\x0c\x41rmFKRequest\x12=\n\x0c\x61rm_position\x18\x01 \x01(\x0b\x32\'.reachy.sdk.kinematics.ArmJointPosition\"]\n\rArmFKSolution\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12;\n\x0c\x65nd_effector\x18\x02 \x01(\x0b\x32%.reachy.sdk.kinematics.ArmEndEffector\"w\n\x0c\x41rmIKRequest\x12\x35\n\x06target\x18\x01 \x01(\x0b\x32%.reachy.sdk.kinematics.ArmEndEffector\x12\x30\n\x02q0\x18\x02 \x01(\x0b\x32$.reachy.sdk.kinematics.JointPosition\"_\n\rArmIKSolution\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12=\n\x0c\x61rm_position\x18\x02 \x01(\x0b\x32\'.reachy.sdk.kinematics.ArmJointPosition*\x1e\n\x07\x41rmSide\x12\x08\n\x04LEFT\x10\x00\x12\t\n\x05RIGHT\x10\x01\x32\xc5\x01\n\rArmKinematics\x12Y\n\x0c\x43omputeArmFK\x12#.reachy.sdk.kinematics.ArmFKRequest\x1a$.reachy.sdk.kinematics.ArmFKSolution\x12Y\n\x0c\x43omputeArmIK\x12#.reachy.sdk.kinematics.ArmIKRequest\x1a$.reachy.sdk.kinematics.ArmIKSolutionb\x06proto3')

_ARMSIDE = DESCRIPTOR.enum_types_by_name['ArmSide']
ArmSide = enum_type_wrapper.EnumTypeWrapper(_ARMSIDE)
LEFT = 0
RIGHT = 1


_ARMENDEFFECTOR = DESCRIPTOR.message_types_by_name['ArmEndEffector']
_ARMJOINTPOSITION = DESCRIPTOR.message_types_by_name['ArmJointPosition']
_ARMFKREQUEST = DESCRIPTOR.message_types_by_name['ArmFKRequest']
_ARMFKSOLUTION = DESCRIPTOR.message_types_by_name['ArmFKSolution']
_ARMIKREQUEST = DESCRIPTOR.message_types_by_name['ArmIKRequest']
_ARMIKSOLUTION = DESCRIPTOR.message_types_by_name['ArmIKSolution']
ArmEndEffector = _reflection.GeneratedProtocolMessageType('ArmEndEffector', (_message.Message,), {
  'DESCRIPTOR' : _ARMENDEFFECTOR,
  '__module__' : 'arm_kinematics_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.kinematics.ArmEndEffector)
  })
_sym_db.RegisterMessage(ArmEndEffector)

ArmJointPosition = _reflection.GeneratedProtocolMessageType('ArmJointPosition', (_message.Message,), {
  'DESCRIPTOR' : _ARMJOINTPOSITION,
  '__module__' : 'arm_kinematics_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.kinematics.ArmJointPosition)
  })
_sym_db.RegisterMessage(ArmJointPosition)

ArmFKRequest = _reflection.GeneratedProtocolMessageType('ArmFKRequest', (_message.Message,), {
  'DESCRIPTOR' : _ARMFKREQUEST,
  '__module__' : 'arm_kinematics_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.kinematics.ArmFKRequest)
  })
_sym_db.RegisterMessage(ArmFKRequest)

ArmFKSolution = _reflection.GeneratedProtocolMessageType('ArmFKSolution', (_message.Message,), {
  'DESCRIPTOR' : _ARMFKSOLUTION,
  '__module__' : 'arm_kinematics_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.kinematics.ArmFKSolution)
  })
_sym_db.RegisterMessage(ArmFKSolution)

ArmIKRequest = _reflection.GeneratedProtocolMessageType('ArmIKRequest', (_message.Message,), {
  'DESCRIPTOR' : _ARMIKREQUEST,
  '__module__' : 'arm_kinematics_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.kinematics.ArmIKRequest)
  })
_sym_db.RegisterMessage(ArmIKRequest)

ArmIKSolution = _reflection.GeneratedProtocolMessageType('ArmIKSolution', (_message.Message,), {
  'DESCRIPTOR' : _ARMIKSOLUTION,
  '__module__' : 'arm_kinematics_pb2'
  # @@protoc_insertion_point(class_scope:reachy.sdk.kinematics.ArmIKSolution)
  })
_sym_db.RegisterMessage(ArmIKSolution)

_ARMKINEMATICS = DESCRIPTOR.services_by_name['ArmKinematics']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ARMSIDE._serialized_start=692
  _ARMSIDE._serialized_end=722
  _ARMENDEFFECTOR._serialized_start=65
  _ARMENDEFFECTOR._serialized_end=175
  _ARMJOINTPOSITION._serialized_start=177
  _ARMJOINTPOSITION._serialized_end=298
  _ARMFKREQUEST._serialized_start=300
  _ARMFKREQUEST._serialized_end=377
  _ARMFKSOLUTION._serialized_start=379
  _ARMFKSOLUTION._serialized_end=472
  _ARMIKREQUEST._serialized_start=474
  _ARMIKREQUEST._serialized_end=593
  _ARMIKSOLUTION._serialized_start=595
  _ARMIKSOLUTION._serialized_end=690
  _ARMKINEMATICS._serialized_start=725
  _ARMKINEMATICS._serialized_end=922
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
import sensor_pb2 as sensor__pb2


class SensorServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetAllForceSensorsId = channel.unary_unary(
                '/reachy.sdk.joint.SensorService/GetAllForceSensorsId',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=sensor__pb2.SensorsId.FromString,
                )
        self.GetSensorsState = channel.unary_unary(
                '/reachy.sdk.joint.SensorService/GetSensorsState',
                request_serializer=sensor__pb2.SensorsStateRequest.SerializeToString,
                response_deserializer=sensor__pb2.SensorsState.FromString,
                )
        self.StreamSensorStates = channel.unary_stream(
                '/reachy.sdk.joint.SensorService/StreamSensorStates',
                request_serializer=sensor__pb2.StreamSensorsStateRequest.SerializeToString,
                response_deserializer=sensor__pb2.SensorsState.FromString,
                )


class SensorServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetAllForceSensorsId(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSensorsState(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StreamSensorStates(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SensorServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetAllForceSensorsId': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAllForceSensorsId,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=sensor__pb2.SensorsId.SerializeToString,
            ),
            'GetSensorsState': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSensorsState,
                    request_deserializer=sensor__pb2.SensorsStateRequest.FromString,
                    response_serializer=sensor__pb2.SensorsState.SerializeToString,
            ),
            'StreamSensorStates': grpc.unary_stream_rpc_method_handler(
                    servicer.StreamSensorStates,
                    request_deserializer=sensor__pb2.StreamSensorsStateRequest.FromString,
                    response_serializer=sensor__pb2.SensorsState.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'reachy.sdk.joint.SensorService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class SensorService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetAllForceSensorsId(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/reachy.sdk.joint.SensorService/GetAllForceSensorsId',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            sensor__pb2.SensorsId.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetSensorsState(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/reachy.sdk.joint.SensorService/GetSensorsState',
            sensor__pb2.SensorsStateRequest.SerializeToString,
            sensor__pb2.SensorsState.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StreamSensorStates(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/reachy.sdk.joint.SensorService/StreamSensorStates',
            sensor__pb2.StreamSensorsStateRequest.SerializeToString,
            sensor__pb2.SensorsState.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
